@@ -2,10 +2,10 @@
 #define RZ_BUILD_VERSION_H
 
 #define RZ_VERSION_MAJOR 0
-#define RZ_VERSION_MINOR 6
+#define RZ_VERSION_MINOR 8
 #define RZ_VERSION_PATCH 1
-#define RZ_VERSION_NUMBER 6001
-#define RZ_VERSION "0.6.1"
+#define RZ_VERSION_NUMBER 8001
+#define RZ_VERSION "0.8.1"
 /* #undef RZ_PACKAGER_VERSION */
 /* #undef RZ_PACKAGER */
-#endif
+#endif /* RZ_BUILD_VERSION_H */
